/**
 ** RegistroAct.java
 **
 ** Copyright (C) 1992, 1999, 2007, 2011 Mariano Alvarez Fernandez
 ** [e-mail: malfer at telefonica.net]
 **
 ** This file is part of the Parchis4A program.
 **
 ** Parchis4A is free software: you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation, either version 3 of the License, or
 ** (at your option) any later version.
 **
 ** Parchis4A is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
 ** along with Parchis4A.  If not, see <http://www.gnu.org/licenses/>.
 **
 **/

package com.fgrim.parchis4a;

import android.app.ListActivity;
import android.content.Context;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.TableRow;
import android.widget.TextView;

public class RegistroAct extends ListActivity {

	private Resources resG;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        
        resG = getResources();
    	String s = resG.getString(R.string.reg_activity) + ", " +
    	    Parchis4A.mRegistro.getTotal() + " "; 
    	s += (Parchis4A.mRegistro.getTotal() == 1) ? resG.getString(R.string.reg_partida) :
    		resG.getString(R.string.reg_partidas);
    	this.setTitle(s);

    	setListAdapter(new RegListAdapter(this));
    	getListView().setDividerHeight(2);
    }
    
    @Override
    protected void onListItemClick(ListView l, View v, int pos, long id) {    
       ((RegListAdapter)getListAdapter()).toggle(pos);
    }
    
    private class RegListAdapter extends BaseAdapter {

        private LayoutInflater mInflater;
        private Context mContext;

    	public RegListAdapter(Context context) {
            mContext = context;
            mInflater = LayoutInflater.from(mContext);
        }

        public int getCount() {
            return Parchis4A.mRegistro.size();
        }

        public Object getItem(int pos) {
            return pos;
        }

        public long getItemId(int pos) {
            return pos;
        }

        public View getView(int pos, View convertView, ViewGroup parent) {
            ViewHolder holder;
            
            if (convertView == null) {
                convertView = mInflater.inflate(R.layout.regp_layout, null);
                holder = new ViewHolder();
                holder.icon = (ImageView) convertView.findViewById(R.id.regp_icon);
                holder.np_text = (TextView) convertView.findViewById(R.id.regp_np_text);
                holder.exp_ll = (LinearLayout) convertView.findViewById(R.id.regp_exp_ll);
                holder.tr[0] = (TableRow) convertView.findViewById(R.id.regp_r1);
                holder.tr[1] = (TableRow) convertView.findViewById(R.id.regp_r2);
                holder.tr[2] = (TableRow) convertView.findViewById(R.id.regp_r3);
                holder.tr[3] = (TableRow) convertView.findViewById(R.id.regp_r4);
                holder.lr[0] = (TextView) convertView.findViewById(R.id.regp_l1);
                holder.lr[1] = (TextView) convertView.findViewById(R.id.regp_l2);
                holder.lr[2] = (TextView) convertView.findViewById(R.id.regp_l3);
                holder.lr[3] = (TextView) convertView.findViewById(R.id.regp_l4);
                convertView.setTag(holder);
            } else {
                holder = (ViewHolder) convertView.getTag();
            }
            RegPartida rp = Parchis4A.mRegistro.getRp(pos);
        	Bitmap bmst = BMPlayerGroup.Generate(resG, rp.dp, false);
        	holder.icon.setImageBitmap(bmst);
        	String s = rp.numpartidas + " ";
        	s += (rp.numpartidas == 1) ? resG.getString(R.string.reg_partida) :
        		resG.getString(R.string.reg_partidas);
            holder.np_text.setText(s);
            holder.exp_ll.setVisibility(rp.expandir ? View.VISIBLE : View.GONE);
            for (int c=0; c<4; c++) {
            	if (rp.dp.tipo_jugador[c] == DefPartida.NOJUEGA) {
            		holder.tr[c].setVisibility(View.GONE);
            	} else {
            		holder.tr[c].setVisibility(View.VISIBLE);
            		holder.lr[c].setText(rp.ranking(c));
            	}
            }
            return convertView;
        }

        public void toggle(int pos) {
            RegPartida rp = Parchis4A.mRegistro.getRp(pos);
            rp.expandir = !rp.expandir;
            notifyDataSetChanged();
        }
    }

    static class ViewHolder {
        ImageView icon;
        TextView np_text;
        LinearLayout exp_ll;
        TableRow tr[] = new TableRow[4];
        TextView lr[] = new TextView[4];
    }
}